Module org.refcodes.generator
module org.refcodes.generator
-
Packages
ExportsPackageDescriptionThis artifact provides word morphs mass production functionality for generating arbitrary distinct IDs similar to UUIDs (as of theUniqueIdGeneratortype) or for generating permutations of words with a given alphabet and permutation rules (as of theAlphabetCounteralongside theAlphabetCounterCompositetypes) as well as multi threading concurrency support (as of theConcurrentBufferedGeneratorDecoratorand theThreadLocalBufferedGeneratorDecoratortypes) for suchGenerator(Iterator) types.