All Classes and Interfaces
Class
Description
The
AbstractCounterComposite combines several Counter
instances which to use when generating data by daisy chaining the provided
generator instances (end of counter 1 increases counter 2, end of counter 2
increases counter 3, ..., end of counter n-1 increases counter n, the end of
a counter is determined with AbstractCounterComposite.hasNext() and a counter is increased by
next()).The
AlphabetCounter generates values by counting with an an alphabet
of "digits", a decimal alphabet would contain the characters "0", "1", "2",
"3", "4", "5", "6", "7", "8" and "9", a hexadecimal alphabet would contain
the characters "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "A", "B",
"C", "D", "E", "F".The
AlphabetCounterComposite creates a IdCounterComposite
composed of AlphabetCounter instances which's alphabets are retrieved
from expressions each (to be combined to a single IdCounter).The
AlphabetCounterMetrics define the metrics for configuring an
AlphabetCounter such as the characters used as alphabet and the
counter's min and max lengths (duplicate definitions of characters are
ignored).Base interface for a
Generator using a buffer being filled upon
demand or time schedule and which's buffering functionality may be suspended
(Suspendable.suspend()) so that the Generator does only emit elements
already present in the puffer till all elements in the buffer are expended
(and does not place any new elements into the buffer to be emitted).The
ConcurrentBufferedGeneratorDecorator decorates a
Generator with read-ahead functionality by buffering generated IDs
till a predefined maximum is reached and refilling the buffer periodically
upon dropping below a threshold.A
Counter is a Generator with means to reset the
Counter state to its initial position (value) from which to begin
counting again, e.g. when hasNext() returns false, then calling
Resetable.reset() will make the Counter instance to start again from
the very first beginning and hasNext() will return true until the
"end" of the countable elements has been reached (by consuming them with
next()).A
Generator generates objects of a dedicated type in mass production.The
IdCounterComposite combines several IdCounter instances
which to use when generating data by daisy chaining the provided generator
instances (end of counter 1 increases counter 2, end of counter 2 increases
counter 3, ..., end of counter n-1 increases counter n, the end of a counter
is determined with AbstractCounterComposite.hasNext() and a counter is increased by
IdCounterComposite.next()).The
IdGenerator interface defines generator functionality for
String instances.The
SeriesMonitor is a Generator with means to monitor the
last fully processed (completed) ID of the series of generated IDs with all
preceding generated IDs also being fully processed (completed): All IDs till
the last fully processed (completed) ID have been processed.The
SeriesMonitorDecorator decorates a Generator with means
to monitor the last fully processed (completed) ID of the series of generated
IDs with all preceding generated IDs also being fully processed (completed):
All IDs till the last fully processed (completed) ID have been processed.The
ThreadLocalBufferedGeneratorDecorator decorates a
Generator with read-ahead functionality by buffering generated IDs on
a per Thread basis: The resulting Generator is thread safe!.The
UniqueIdGenerator is an implementation of the Generator
capable of generating TID String instances unique on the system on
which them were generated to IDs generated with the same
UniqueIdGenerator on another system.Defines the type of BASE-64 encoding to use for generated IDs.
The Class UniqueIdGeneratorSingleton.